@@ -1,10 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "isearch-project" "0.2.6"
+(define-package "isearch-project" "20260101.600"
   "Incremental search through the whole project."
-  '((emacs "26.1")
+  '((emacs "27.1")
     (f     "0.20.0"))
   :url "https://github.com/jcs-elpa/isearch-project"
-  :commit "1077b395e1c34a734120faf1f3a7feae6dc4d9c5"
-  :revdesc "1077b395e1c3"
+  :commit "e67c997c9b36690a8b1b7712ff1ba9664020d8b2"
+  :revdesc "e67c997c9b36"
+  :keywords '("convenience" "search")
   :authors '(("Jen-Chieh" . "jcs090218@gmail.com"))
   :maintainers '(("Jen-Chieh" . "jcs090218@gmail.com")))
